==> atmc-http-0.0.2.0014-sources.jar: com/digiwin/athena/atmc/http/domain/Backlog.java <==
package com.digiwin.athena.atmc.http.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

import java.time.LocalDateTime;
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Accessors(chain = true)
@TableName(autoResultMap = true)
public class Backlog extends BaseEntity<Backlog>{
    @TableId()
    private Long id;

    private String name;

    private Long taskId;

    private Long activityId;

    private String performerId;
    private String tenantId;
    private String content;
    private String uri;
    private LocalDateTime startTime;
    private LocalDateTime endTime;
    private Boolean closed;
    /**
     * 2021-10-18，zhujg
     * 已停用，请使有用 BpmActivityWorkitem.importance
     */
    private Integer importance;
    /**
     * 2021-10-18，zhujg
     * 已停用，请使有用 BpmActivityWorkitem.importance
     */
    private String importanceSource;
    private Integer type=1;
    private Long bpmActivityId;
    /**
     * 已读次数
     */
    private Integer readCount = 0;

    /**
     * 执行者姓名
     */
    private String performerName;

    private Long bpmActivityStepId;

    private LocalDateTime createTime;

    /**
     * 转派的来源backlog.id
     * -- 已废弃--
     */
    private Long reassignFromId=0L;

    /**
     * 签核状态，BPM签核状态,空-无状态，reassign-转派,reexecute-退回
     * -- 2021-08-06 迭代18，zhujg,废弃，使用 bpm_activity_workitem.approval_state
     */
    @Deprecated
    private String approvalState = "";

    /**
     * 缓存任务的summaryLayout
     */
    private String taskSummaryLayout;

    /**
     * 缓存项目的summaryLayout
     */
    private String projectSummaryLayout;

    /**
     * 原逾期的backlog.Id
     */
    private Long overdueBacklogId=0L;

    /**
     * 来源租户
     */
    private String sourceTenantId;

    /**
     * 来源租户名称
     */
    private String sourceTenantName;
    /**
     * 实际处理人
     */
    private String executor;

    /**
     * 是否是外部任务 （0 - 否，1- 是）
     */
    private Integer isExternal;

    /**
     * 引擎类型
     * FlowEngine BP
     * TaskEngine 任务引擎
     */
    private String engineType;

    @TableField(exist = false)
    private String activityCode;

    @TableField(exist = false)
    private Long projectId;

}

==> atmc-http-0.0.2.0038-sources.jar: com/digiwin/athena/atmc/http/domain/Backlog.java <==
package com.digiwin.athena.atmc.http.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

import java.time.LocalDateTime;
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Accessors(chain = true)
@TableName(autoResultMap = true)
public class Backlog extends BaseEntity<Backlog>{
    @TableId()
    private Long id;

    private String name;

    private Long taskId;

    private Long activityId;

    private String performerId;
    private String tenantId;
    private String content;

    /**
     * 格式："{"zh_CN":"xxx", "zh_TW": "xxxxx", "en_US": "xxxxxx"}"
     */
    private String withName;
    /**
     * 格式："{"zh_CN":"xxx", "zh_TW": "xxxxx", "en_US": "xxxxxx"}"
     */
    private String contentWithName;
    private String uri;
    private LocalDateTime startTime;
    private LocalDateTime endTime;
    private Boolean closed;
    /**
     * 2021-10-18，zhujg
     * 已停用，请使有用 BpmActivityWorkitem.importance
     */
    private Integer importance;
    /**
     * 2021-10-18，zhujg
     * 已停用，请使有用 BpmActivityWorkitem.importance
     */
    private String importanceSource;
    private Integer type=1;
    private Long bpmActivityId;
    /**
     * 已读次数
     */
    private Integer readCount = 0;

    /**
     * 执行者姓名
     */
    private String performerName;

    private Long bpmActivityStepId;

    private LocalDateTime createTime;

    /**
     * 转派的来源backlog.id
     * -- 已废弃--
     */
    private Long reassignFromId=0L;

    /**
     * 签核状态，BPM签核状态,空-无状态，reassign-转派,reexecute-退回
     * -- 2021-08-06 迭代18，zhujg,废弃，使用 bpm_activity_workitem.approval_state
     */
    @Deprecated
    private String approvalState = "";

    /**
     * 缓存任务的summaryLayout
     */
    private String taskSummaryLayout;

    /**
     * 缓存项目的summaryLayout
     */
    private String projectSummaryLayout;

    /**
     * 原逾期的backlog.Id
     */
    private Long overdueBacklogId=0L;

    /**
     * 来源租户
     */
    private String sourceTenantId;

    /**
     * 来源租户名称
     */
    private String sourceTenantName;
    /**
     * 实际处理人
     */
    private String executor;

    /**
     * 是否是外部任务 （0 - 否，1- 是）
     */
    private Integer isExternal;

    /**
     * 引擎类型
     * FlowEngine BP
     * TaskEngine 任务引擎
     */
    private String engineType;

    @TableField(exist = false)
    private String activityCode;

    @TableField(exist = false)
    private Long projectId;

}
